==> igniteui-webcomponents-spreadsheet-4.6.0.tgz: package/esm5/lib/EditModeWorkbookFontInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, toNullable, Boolean_$type, Nullable$1, Number_$type, String_$type, typeGetValue, markType } from "igniteui-webcomponents-core";
import { WorkbookColorInfo } from "igniteui-webcomponents-excel";
import { FontSuperscriptSubscriptStyle_$type } from "igniteui-webcomponents-excel";
import { FontUnderlineStyle_$type } from "igniteui-webcomponents-excel";
import { WorksheetCellFormatData } from "igniteui-webcomponents-excel";
import { EqualityComparer$1 } from "igniteui-webcomponents-core";
import { stringEmpty } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var EditModeWorkbookFontInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EditModeWorkbookFontInfo, _super);
    function EditModeWorkbookFontInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = toNullable(Boolean_$type, null);
        _this.c = null;
        _this.d = 0;
        _this.f = toNullable(Boolean_$type, null);
        _this.i = null;
        _this.g = toNullable(Boolean_$type, null);
        _this.a = 0;
        _this.b = 0;
        return _this;
    }
    EditModeWorkbookFontInfo.prototype.h = function (a) {
        var b = null;
        var c = this.k(Nullable$1.$.specialize(Boolean_$type), this.e, a.e, "Bold", b);
        this.e = c.p0;
        b = c.p3;
        var d = this.k(WorkbookColorInfo.$, this.c, a.c, "ColorInfo", b);
        this.c = d.p0;
        b = d.p3;
        var e = this.k(Number_$type, this.d, a.d, "Height", b);
        this.d = e.p0;
        b = e.p3;
        var f = this.k(Nullable$1.$.specialize(Boolean_$type), this.f, a.f, "Italic", b);
        this.f = f.p0;
        b = f.p3;
        var g = this.k(String_$type, this.i, a.i, "Name", b);
        this.i = g.p0;
        b = g.p3;
        var h = this.k(Nullable$1.$.specialize(Boolean_$type), this.g, a.g, "Strikeout", b);
        this.g = h.p0;
        b = h.p3;
        var i = this.k(FontSuperscriptSubscriptStyle_$type, this.a, a.a, "SuperscriptSubscriptStyle", b);
        this.a = i.p0;
        b = i.p3;
        var j = this.k(FontUnderlineStyle_$type, this.b, a.b, "UnderlineStyle", b);
        this.b = j.p0;
        b = j.p3;
        return b;
    };
    EditModeWorkbookFontInfo.prototype.j = function () {
        this.e = toNullable(Boolean_$type, false);
        this.c = WorkbookColorInfo.automatic;
        this.d = typeGetValue(WorksheetCellFormatData._c8(512));
        this.f = toNullable(Boolean_$type, false);
        this.i = WorksheetCellFormatData._c8(2048);
        this.g = toNullable(Boolean_$type, false);
        this.a = 0;
        this.b = 0;
    };
    EditModeWorkbookFontInfo.prototype.k = function ($t, a, b, c, d) {
        if (!EqualityComparer$1.defaultEqualityComparerValue($t).equalsC(a, b)) {
            a = b;
            if (d == null) {
                d = c;
            }
            else {
                d = stringEmpty();
            }
        }
        return {
            p0: a,
            p3: d
        };
    };
    EditModeWorkbookFontInfo.$t = markType(EditModeWorkbookFontInfo, 'EditModeWorkbookFontInfo');
    return EditModeWorkbookFontInfo;
}(Base));
export { EditModeWorkbookFontInfo };

==> igniteui-webcomponents-spreadsheet-4.8.1.tgz: package/esm5/lib/EditModeWorkbookFontInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, toNullable, Boolean_$type, Nullable$1, Number_$type, String_$type, typeGetValue, markType } from "igniteui-webcomponents-core";
import { WorkbookColorInfo } from "igniteui-webcomponents-excel";
import { FontSuperscriptSubscriptStyle_$type } from "igniteui-webcomponents-excel";
import { FontUnderlineStyle_$type } from "igniteui-webcomponents-excel";
import { WorksheetCellFormatData } from "igniteui-webcomponents-excel";
import { EqualityComparer$1 } from "igniteui-webcomponents-core";
import { stringEmpty } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var EditModeWorkbookFontInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EditModeWorkbookFontInfo, _super);
    function EditModeWorkbookFontInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = toNullable(Boolean_$type, null);
        _this.c = null;
        _this.d = 0;
        _this.f = toNullable(Boolean_$type, null);
        _this.i = null;
        _this.g = toNullable(Boolean_$type, null);
        _this.a = 0;
        _this.b = 0;
        return _this;
    }
    EditModeWorkbookFontInfo.prototype.h = function (a) {
        var b = null;
        var c = this.k(Nullable$1.$.specialize(Boolean_$type), this.e, a.e, "Bold", b);
        this.e = c.p0;
        b = c.p3;
        var d = this.k(WorkbookColorInfo.$, this.c, a.c, "ColorInfo", b);
        this.c = d.p0;
        b = d.p3;
        var e = this.k(Number_$type, this.d, a.d, "Height", b);
        this.d = e.p0;
        b = e.p3;
        var f = this.k(Nullable$1.$.specialize(Boolean_$type), this.f, a.f, "Italic", b);
        this.f = f.p0;
        b = f.p3;
        var g = this.k(String_$type, this.i, a.i, "Name", b);
        this.i = g.p0;
        b = g.p3;
        var h = this.k(Nullable$1.$.specialize(Boolean_$type), this.g, a.g, "Strikeout", b);
        this.g = h.p0;
        b = h.p3;
        var i = this.k(FontSuperscriptSubscriptStyle_$type, this.a, a.a, "SuperscriptSubscriptStyle", b);
        this.a = i.p0;
        b = i.p3;
        var j = this.k(FontUnderlineStyle_$type, this.b, a.b, "UnderlineStyle", b);
        this.b = j.p0;
        b = j.p3;
        return b;
    };
    EditModeWorkbookFontInfo.prototype.j = function () {
        this.e = toNullable(Boolean_$type, false);
        this.c = WorkbookColorInfo.automatic;
        this.d = typeGetValue(WorksheetCellFormatData._da(512));
        this.f = toNullable(Boolean_$type, false);
        this.i = WorksheetCellFormatData._da(2048);
        this.g = toNullable(Boolean_$type, false);
        this.a = 0;
        this.b = 0;
    };
    EditModeWorkbookFontInfo.prototype.k = function ($t, a, b, c, d) {
        if (!EqualityComparer$1.defaultEqualityComparerValue($t).equalsC(a, b)) {
            a = b;
            if (d == null) {
                d = c;
            }
            else {
                d = stringEmpty();
            }
        }
        return {
            p0: a,
            p3: d
        };
    };
    EditModeWorkbookFontInfo.$t = markType(EditModeWorkbookFontInfo, 'EditModeWorkbookFontInfo');
    return EditModeWorkbookFontInfo;
}(Base));
export { EditModeWorkbookFontInfo };
